@@ -14,6 +14,9 @@ BEGIN {
 }
 
 
+use SDL::Internal::Loader;
+internal_load_dlls(__PACKAGE__);
+
 bootstrap SDL::Net;
 
 #use constant
